==> billogram-foundation-4.6.4.tgz: package/modules/components/datepicker/DatepickerRangeState.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';


export default ({
    block,
    Component
}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(Component !== undefined, 'Missing Datepicker component');

    return React.createClass({

        displayName: `${Component.displayName}Range`,

        mixins: [PureRenderMixin],

        propTypes: {
            end: PropTypes.shape({
                initialValue: PropTypes.number,
                onChange: PropTypes.func
            }),
            start: PropTypes.shape({
                initialValue: PropTypes.number,
                onChange: PropTypes.func
            })
        },

        getInitialState() {
            const { start, end } = this.props;
            return {
                start: {
                    value: start.initialValue
                },
                end: {
                    value: end.initialValue
                }
            };
        },

        onChangeStart(value) {
            const { start } = this.props;
            this.setState((prevState) => {
                return {
                    ...prevState,
                    start: {
                        ...prevState.start,
                        value
                    }
                };
                // small "hack", since we cannot deep merge props.
            }, () => start.onChange && start.onChange(value));
        },

        onChangeEnd(value) {
            const { end } = this.props;
            this.setState((prevState) => {
                return {
                    ...prevState,
                    end: {
                        ...prevState.end,
                        value
                    }
                };
                // small "hack", since we cannot deep merge props.
            }, () => end.onChange && end.onChange(value));
        },

        render() {
            return (
                <div className={ block() }>
                    <Component
                        { ...this.props.start }
                        { ...this.state.start }
                        onChange={ this.onChangeStart }
                        ui="transparent" />
                    <span className={ block('separator') }>&#65293;</span>
                    <Component
                        { ...this.props.end }
                        { ...this.state.end }
                        onChange={ this.onChangeEnd }
                        ui="transparent" />
                </div>
            );
        }

    });

};

==> billogram-foundation-4.8.1.tgz: package/modules/components/datepicker/DatepickerRangeState.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';


export default ({
    block,
    Component,
}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(Component !== undefined, 'Missing Datepicker component');

    return React.createClass({

        displayName: `${Component.displayName}Range`,

        mixins: [PureRenderMixin],

        propTypes: {
            end: PropTypes.shape({
                initialValue: PropTypes.number,
                onChange: PropTypes.func,
            }),
            start: PropTypes.shape({
                initialValue: PropTypes.number,
                onChange: PropTypes.func,
            }),
        },

        getInitialState() {
            const { start, end } = this.props;
            return {
                start: {
                    value: start.initialValue,
                },
                end: {
                    value: end.initialValue,
                },
            };
        },

        onChangeStart(value) {
            const { start } = this.props;
            this.setState((prevState) => {
                return {
                    ...prevState,
                    start: {
                        ...prevState.start,
                        value,
                    },
                };
                // small "hack", since we cannot deep merge props.
            }, () => start.onChange && start.onChange(value));
        },

        onChangeEnd(value) {
            const { end } = this.props;
            this.setState((prevState) => {
                return {
                    ...prevState,
                    end: {
                        ...prevState.end,
                        value,
                    },
                };
                // small "hack", since we cannot deep merge props.
            }, () => end.onChange && end.onChange(value));
        },

        render() {
            return (
                <div className={ block() }>
                    <Component
                        { ...this.props.start }
                        { ...this.state.start }
                        onChange={ this.onChangeStart }
                        ui="transparent" />
                    <span className={ block('separator') }>&#65293;</span>
                    <Component
                        { ...this.props.end }
                        { ...this.state.end }
                        onChange={ this.onChangeEnd }
                        ui="transparent" />
                </div>
            );
        },

    });

};
